<?php
/**
 * porpok functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package porpok
 */

define( 'PORPOK_THEME_NAME', 'porpok' );
define( 'PORPOK_THEME_VERSION', '1.0.0' );

define('PORPOK_PRO_URL', 'http://topgle.com/porpok/');

if ( ! function_exists( 'porpok_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function porpok_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on porpok, use a find and replace
		 * to change 'porpok' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'porpok', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 300 );

		add_image_size( 'porpok-slider', 740 , 350, true );
		add_image_size( 'porpok-thumb', 480 , 350, true );


		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1'	=> esc_html__( 'Primary', 'porpok' ),
			'menu-2'	=> esc_html__( 'Secondary', 'porpok' ),
			'menu-3'	=> esc_html__( 'Footer', 'porpok' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'porpok_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// This theme styles the visual editor to resemble the theme style.
		$google_font_url = str_replace( ',', '%2C', 'https://fonts.googleapis.com/css?family=Lato:400,700|Montserrat:700' );
		add_editor_style( array( 'css/editor-style.css', $google_font_url ) );

	}
endif;
add_action( 'after_setup_theme', 'porpok_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function porpok_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'porpok_content_width', 640 );
}
add_action( 'after_setup_theme', 'porpok_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function porpok_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'porpok' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'porpok' ),
		'before_widget' => '<section id="%1$s" class="fbox widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="swidget"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Under Menu Ad', 'porpok' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'porpok' ),
		'before_widget' => '<div id="%1$s" class="ads-top %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="swidget"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );
}
add_action( 'widgets_init', 'porpok_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function porpok_scripts() {
	wp_enqueue_style( 'porpok-font-google', 'https://fonts.googleapis.com/css?family=Lato:400,700|Montserrat:400,500,700' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/all.css' );
	wp_enqueue_style( 'flexslider-style', get_template_directory_uri() . '/css/flexslider.css');
	wp_enqueue_style( 'porpok-style', get_stylesheet_uri() );

	wp_enqueue_script( 'porpok-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20170823', true );
	wp_enqueue_script( 'porpok-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20170823', true );
	wp_enqueue_script( 'porpok-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array('jquery'), '20150423', true );
	wp_enqueue_script( 'porpok-script', get_template_directory_uri() . '/js/script.js', array(), '20160720', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'porpok_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Widgets
 */
require get_template_directory() . '/inc/widget.php';


