<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package porpok
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'porpok' ); ?></a>

	<?php if ( get_header_image() ) : ?>
		<div id="site-header" class="clearfix" >
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
				<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?> <?php echo get_bloginfo( 'description', 'display' ); ?>">
			</a>
		</div>
	<?php endif; ?>

	<header id="masthead" class="sheader site-header clearfix">
		<div class="clearfix">
		
			<div class="content-wrap">
				<div class="search-style-one">
					<div class="overlay overlay-slideleft">
						<div class="search-row inner clearfix">
							<form method="get" id="searchform" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
								<a href="#" class="overlay-close"><i class="fa fa-times fa-1" aria-hidden="true"></i></a>
								<input type="text" name="s" id="s" value="<?php echo get_search_query(); ?>" placeholder="<?php esc_attr_e('Search in Site', 'porpok'); ?>" />
							</form>
						</div>
					</div>
				</div>

				
				<?php if ( has_custom_logo() ) : ?>

					<div class="site-branding branding-logo">
						<?php the_custom_logo(); ?>
					</div><!-- .site-branding -->

				<?php else : ?>

					<div class="site-branding">

						<?php if ( is_front_page() && is_home() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
						<?php
						endif;

						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
						<?php
						endif;
						?>

					</div><!-- .site-branding -->

				<?php
				endif;
				?>
				
				<div class="search">
					<a class="btn-search" href="#"><i class="fa fa-search"></i></a>
				</div>

				<nav id="primary-site-navigation" class="primary-menu main-navigation">

					<a href="#" id="primary-pull" class="smenu-hide toggle-mobile-menu menu-toggle" aria-controls="secondary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'porpok' ); ?></a>
					
					<?php
						wp_nav_menu( array(
							'theme_location'	=> 'menu-1',
							'menu_id'			=> 'primary-menu',
							'menu_class'		=> 'pmenu'
						) );
					?>

				</nav><!-- #primary-site-navigation -->
			</div>
		</div>

		<div class="super-menu clearfix">
			<div class="super-menu-inner">

				<a href="#" id="secondary-pull" class="toggle-mobile-menu menu-toggle" aria-controls="secondary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'porpok' ); ?></a>

			</div>
		</div>

		<nav id="secondary-site-navigation" class="secondary-menu main-navigation clearfix">

			<div class="content-wrap">

				<?php
					wp_nav_menu( array(
						'theme_location'	=> 'menu-2',
						'menu_id'			=> 'secondary-menu',
						'menu_class'		=> 'smenu'
					) );
				?>

			</div>

		</nav><!-- #secondary-site-navigation -->

	</header><!-- #masthead -->

	<div class="content-wrap">
		<?php
		if ( is_active_sidebar( 'sidebar-2' ) ) :

			dynamic_sidebar( 'sidebar-2' );

		endif;
		?>
	</div>

	<div id="content" class="site-content clearfix">
		<div class="content-wrap">
